import $ from "jquery";
import HSDropdown from "@preline/dropdown";
import HSDataTable, { IDataTableOptions } from "@preline/datatable";
import { ConfigColumnDefs, AjaxSettings } from "datatables.net-dt";

const emptyTableHtml: string = `
    <div class="max-w-md w-full min-h-[400px] flex flex-col justify-center mx-auto px-6 py-4">
        <div class="flex justify-center items-center size-[46px] bg-gray-100 rounded-lg dark:bg-neutral-800">
            <svg class="shrink-0 size-6 text-gray-600 dark:text-neutral-400" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24" width="24" height="24" stroke="currentColor" stroke-width="2" fill="none" stroke-linecap="round" stroke-linejoin="round"><path d="M4 11a9 9 0 0 1 9 9"></path><path d="M4 4a16 16 0 0 1 16 16"></path><circle cx="5" cy="19" r="1"></circle></svg>
        </div>
        <h2 class="mt-5 font-semibold text-gray-800 dark:text-white">
            No results found
        </h2>
        <p class="mt-2 text-sm text-gray-600 dark:text-neutral-400">
            Create a subscription and it will appear here.
        </p>

        <div class="mt-5 flex flex-col sm:flex-row gap-2">
            <button type="button" class="openSubModal-js py-2 px-3 inline-flex justify-center items-center gap-x-2 text-sm font-medium rounded-lg border border-transparent bg-blue-600 text-white hover:bg-blue-700 focus:outline-hidden focus:bg-blue-700 disabled:opacity-50 disabled:pointer-events-none" data-hs-overlay="#subModal">
                <svg class="shrink-0 size-4" xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round"><path d="M5 12h14"/><path d="M12 5v14"/></svg>
                Create a subscription
            </button>
            <button type="button" onclick="alert('not implemented');" class="py-2 px-3 inline-flex items-center gap-x-2 text-sm font-medium rounded-lg border border-gray-200 bg-white text-gray-800 shadow-xs hover:bg-gray-50 focus:outline-hidden focus:bg-gray-50 disabled:opacity-50 disabled:pointer-events-none dark:bg-neutral-800 dark:border-neutral-700 dark:text-white dark:hover:bg-neutral-700 dark:focus:bg-neutral-700">
                Use a Template
            </button>
        </div>
    </div>
`;

const columnDefs: ConfigColumnDefs[] = [];

const ajaxSettings: AjaxSettings = {
    url: ``,
    dataSrc: "data",
    data: (data: unknown) => {
        if (data === undefined) return;
        // TODO
    }
};

const tableOptions: IDataTableOptions = {
    ajax: ajaxSettings,
    serverSide: true,
    processing: true,
    columnDefs: columnDefs,
    pagingOptions: { pageBtnClasses: "hidden" },
    rowSelectingOptions: { selectAllSelector: "#selectAllBox" },
    language: {
        zeroRecords: emptyTableHtml,
        emptyTable: emptyTableHtml,
        loadingRecords: "Placeholder loading message..."
    },
    drawCallback: () => HSDropdown.autoInit(),
    rowCallback: (row: HTMLTableRowElement) => {
        $(row).addClass("bg-white dark:bg-neutral-900");
    }
};

const table: HSDataTable = new HSDataTable(
    $("#table").get(0),
    tableOptions
);